searchNodes=[{"ref":"Mssqlex.html","title":"Mssqlex","type":"module","doc":"Interface for interacting with MS SQL Server via an ODBC driver for Elixir. It implements DBConnection behaviour, using :odbc to connect to the system&#39;s ODBC driver. Requires MS SQL Server ODBC driver, see README for installation instructions."},{"ref":"Mssqlex.html#child_spec/1","title":"Mssqlex.child_spec/1","type":"function","doc":""},{"ref":"Mssqlex.html#prepare_execute/5","title":"Mssqlex.prepare_execute/5","type":"function","doc":""},{"ref":"Mssqlex.html#query/4","title":"Mssqlex.query/4","type":"function","doc":"Executes a query against an MS SQL Server with ODBC. conn expects a Mssqlex process identifier. statement expects a SQL query string. params expects a list of values in one of the following formats: Strings with only valid ASCII characters, which will be sent to the database as strings. Other binaries, which will be converted to UTF16 Little Endian binaries (which is what SQL Server expects for its unicode fields). Decimal structs, which will be encoded as strings so they can be sent to the database with arbitrary precision. Integers, which will be sent as-is if under 10 digits or encoded as strings for larger numbers. Floats, which will be encoded as strings. Time as {hour, minute, sec, usec} tuples, which will be encoded as strings. Dates as {year, month, day} tuples, which will be encoded as strings. Datetime as {{hour, minute, sec, usec}, {year, month, day}} tuples which will be encoded as strings. Note that attempting to insert a value with usec &gt; 0 into a &#39;datetime&#39; or &#39;smalldatetime&#39; column is an error since those column types don&#39;t have enough precision to store usec data. opts expects a keyword list with zero or more of: :preserve_encoding: If true, doesn&#39;t convert returned binaries from UTF16LE to UTF8. Default: false. :mode - set to :savepoint to use a savepoint to rollback to before the query on error, otherwise set to :transaction (default: :transaction); Result values will be encoded according to the following conversions: char and varchar: strings. nchar and nvarchar: strings unless :preserve_encoding is set to true in which case they will be returned as UTF16 Little Endian binaries. int, smallint, tinyint and bigint: integers. float, real, double precision, decimal and numeric: Decimal structs. date: {year, month, day} smalldatetime, datetime, dateime2: {{YY, MM, DD}, {HH, MM, SS, 0}} (note that fractional second data is lost due to limitations of the ODBC adapter. To preserve it you can convert these columns to varchar during selection.) uniqueidentifier: string time, binary, varbinary, rowversion: not currently supported due to adapter limitations. Select statements for columns of these types must convert them to supported types (e.g. varchar)."},{"ref":"Mssqlex.html#query!/4","title":"Mssqlex.query!/4","type":"function","doc":"Executes a query against an MS SQL Server with ODBC. Raises an error on failure. See query/4 for details."},{"ref":"Mssqlex.html#start_link/1","title":"Mssqlex.start_link/1","type":"function","doc":"Connect to a MS SQL Server using ODBC. opts expects a keyword list with zero or more of: :odbc_driver - The driver the adapter will use. environment variable: MSSQL_DVR default value: {ODBC Driver 17 for SQL Server} :hostname - The server hostname. environment variable: MSSQL_HST default value: localhost :instance_name - OPTIONAL. The name of the instance, if using named instances. environment variable: MSSQL_IN :port - OPTIONAL. The server port number. environment variable: MSSQL_PRT :database - The name of the database. environment variable: MSSQL_DB :username - Username. environment variable: MSSQL_UID :password - User&#39;s password. environment variable: MSSQL_PWD :encrypt - Specifies whether data should be encrypted before sending it over the network. environment variable: MSSQL_ENCRYPT :trust_server_certificate - When used with Encrypt, enables encryption using a self-signed server certificate. environment variable: MSSQL_TRUST_SERVER_CERT Mssqlex uses the DBConnection framework and supports all DBConnection options like :idle, :after_connect etc. See DBConnection.start_link/2 for more information. Examples iex&gt; {:ok, pid} = Mssqlex.start_link(database: &quot;mr_microsoft&quot;) {:ok, #PID&lt;0.70.0&gt;}"},{"ref":"Mssqlex.html#stream/4","title":"Mssqlex.stream/4","type":"function","doc":""},{"ref":"Mssqlex.html#t:conn/0","title":"Mssqlex.conn/0","type":"type","doc":"A connection process name, pid or reference. A connection reference is used when making multiple requests to the same connection, see transaction/3."},{"ref":"Mssqlex.html#t:params/0","title":"Mssqlex.params/0","type":"type","doc":""},{"ref":"Mssqlex.Error.html","title":"Mssqlex.Error","type":"exception","doc":"Defines an error returned from the ODBC adapter. message is the full message returned by ODBC odbc_code is an atom representing the returned SQLSTATE or the string representation of the code if it cannot be translated."},{"ref":"Mssqlex.Error.html#t:t/0","title":"Mssqlex.Error.t/0","type":"type","doc":""},{"ref":"Mssqlex.ODBC.html","title":"Mssqlex.ODBC","type":"module","doc":"Adapter to Erlang&#39;s :odbc module. This module is a GenServer that handles communication between Elixir and Erlang&#39;s :odbc module. Transformations are kept to a minimum, primarily just translating binaries to charlists and vice versa. It is used by Mssqlex.Protocol and should not generally be accessed directly."},{"ref":"Mssqlex.ODBC.html#child_spec/1","title":"Mssqlex.ODBC.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"Mssqlex.ODBC.html#commit/1","title":"Mssqlex.ODBC.commit/1","type":"function","doc":"Commits a transaction on the ODBC driver. Note that unless in autocommit mode, all queries are wrapped in implicit transactions and must be committed. pid is the :odbc process id"},{"ref":"Mssqlex.ODBC.html#describe/2","title":"Mssqlex.ODBC.describe/2","type":"function","doc":""},{"ref":"Mssqlex.ODBC.html#disconnect/1","title":"Mssqlex.ODBC.disconnect/1","type":"function","doc":"Disconnects from the ODBC driver. Attempts to roll back any pending transactions. If a pending transaction cannot be rolled back the disconnect still happens without any changes being committed. pid is the :odbc process id"},{"ref":"Mssqlex.ODBC.html#query/4","title":"Mssqlex.ODBC.query/4","type":"function","doc":"Sends a parametrized query to the ODBC driver. Interface to :odbc.param_query/3.See Erlang&#39;s ODBC guide for usage details and examples. pid is the :odbc process id statement is the SQL query string params are the parameters to send with the SQL query opts are options to be passed on to :odbc"},{"ref":"Mssqlex.ODBC.html#rollback/1","title":"Mssqlex.ODBC.rollback/1","type":"function","doc":"Rolls back a transaction on the ODBC driver. pid is the :odbc process id"},{"ref":"Mssqlex.ODBC.html#start_link/2","title":"Mssqlex.ODBC.start_link/2","type":"function","doc":"Starts the connection process to the ODBC driver. conn_str should be a connection string in the format required by your ODBC driver. opts will be passed verbatim to :odbc.connect/2."},{"ref":"Mssqlex.Protocol.html","title":"Mssqlex.Protocol","type":"module","doc":"Implementation of DBConnection behaviour for Mssqlex.ODBC. Handles translation of concepts to what ODBC expects and holds state for a connection. This module is not called directly, but rather through other Mssqlex modules or DBConnection functions."},{"ref":"Mssqlex.Protocol.html#handle_deallocate/4","title":"Mssqlex.Protocol.handle_deallocate/4","type":"function","doc":"Deallocate a cursor declared by c:handle_declare/4 with the database. Return {:ok, result, state} on success and to continue, {:error, exception, state} to return an error and continue, or {:disconnect, exception, state} to return an error and disconnect. This callback is called in the client process. Callback implementation for DBConnection.handle_deallocate/4."},{"ref":"Mssqlex.Protocol.html#handle_declare/4","title":"Mssqlex.Protocol.handle_declare/4","type":"function","doc":"Declare a cursor using a query prepared by c:handle_prepare/3. Return {:ok, query, cursor, state} to return altered query query and cursor cursor for a stream and continue, {:error, exception, state} to return an error and continue or {:disconnect, exception, state} to return an error and disconnect. This callback is called in the client process. Callback implementation for DBConnection.handle_declare/4."},{"ref":"Mssqlex.Protocol.html#handle_fetch/4","title":"Mssqlex.Protocol.handle_fetch/4","type":"function","doc":"Fetch the next result from a cursor declared by c:handle_declare/4. Return {:cont, result, state} to return the result result and continue using cursor, {:halt, result, state} to return the result result and close the cursor, {:error, exception, state} to return an error and close the cursor, {:disconnect, exception, state} to return an error and disconnect. This callback is called in the client process. Callback implementation for DBConnection.handle_fetch/4."},{"ref":"Mssqlex.Protocol.html#handle_first/4","title":"Mssqlex.Protocol.handle_first/4","type":"function","doc":""},{"ref":"Mssqlex.Protocol.html#handle_next/4","title":"Mssqlex.Protocol.handle_next/4","type":"function","doc":""},{"ref":"Mssqlex.Protocol.html#handle_status/2","title":"Mssqlex.Protocol.handle_status/2","type":"function","doc":"Handle getting the transaction status. Return {:idle, state} if outside a transaction, {:transaction, state} if inside a transaction, {:error, state} if inside an aborted transaction, or {:disconnect, exception, state} to error and disconnect. If the callback returns a :disconnect tuples then status/2 will return :error. Callback implementation for DBConnection.handle_status/2."},{"ref":"Mssqlex.Protocol.html#ping/1","title":"Mssqlex.Protocol.ping/1","type":"function","doc":"Called when the connection has been idle for a period of time. Return {:ok, state} to continue or {:disconnect, exception, state} to disconnect. This callback is called if no callbacks have been called after the idle timeout and a client process is not using the state. The idle timeout can be configured by the :idle_interval option. This function can be called whether the connection is checked in or checked out. This callback is called in the connection process. Callback implementation for DBConnection.ping/1."},{"ref":"Mssqlex.Protocol.html#t:cursor/0","title":"Mssqlex.Protocol.cursor/0","type":"type","doc":""},{"ref":"Mssqlex.Protocol.html#t:opts/0","title":"Mssqlex.Protocol.opts/0","type":"type","doc":""},{"ref":"Mssqlex.Protocol.html#t:params/0","title":"Mssqlex.Protocol.params/0","type":"type","doc":""},{"ref":"Mssqlex.Protocol.html#t:query/0","title":"Mssqlex.Protocol.query/0","type":"type","doc":""},{"ref":"Mssqlex.Protocol.html#t:result/0","title":"Mssqlex.Protocol.result/0","type":"type","doc":""},{"ref":"Mssqlex.Protocol.html#t:state/0","title":"Mssqlex.Protocol.state/0","type":"type","doc":"Process state. Includes: :pid: the pid of the ODBC process :mssql: the transaction state. Can be :idle (not in a transaction), :transaction (in a transaction) or :auto_commit (connection in autocommit mode) :conn_opts: the options used to set up the connection."},{"ref":"Mssqlex.Protocol.html#t:status/0","title":"Mssqlex.Protocol.status/0","type":"type","doc":""},{"ref":"Mssqlex.Query.html","title":"Mssqlex.Query","type":"module","doc":"Implementation of DBConnection.Query for Mssqlex. The structure is: name - currently not used. statement - SQL statement to run using :odbc."},{"ref":"Mssqlex.Query.html#t:t/0","title":"Mssqlex.Query.t/0","type":"type","doc":""},{"ref":"Mssqlex.Result.html","title":"Mssqlex.Result","type":"module","doc":"Result struct returned from any successful query. Its fields are: columns - The names of each column in the result set; rows - The result set. A list of tuples, each tuple corresponding to a row, each element in the tuple corresponds to a column; num_rows - The number of fetched or affected rows;"},{"ref":"Mssqlex.Result.html#t:t/0","title":"Mssqlex.Result.t/0","type":"type","doc":""},{"ref":"Mssqlex.Type.html","title":"Mssqlex.Type","type":"module","doc":"Type conversions. Note the :odbc return types for decoding can be found here: http://erlang.org/doc/apps/odbc/databases.html#data-types-"},{"ref":"Mssqlex.Type.html#decode/2","title":"Mssqlex.Type.decode/2","type":"function","doc":"Transforms :odbc return values to Elixir representations."},{"ref":"Mssqlex.Type.html#encode/2","title":"Mssqlex.Type.encode/2","type":"function","doc":"Transforms input params into :odbc params."},{"ref":"Mssqlex.Type.html#t:date/0","title":"Mssqlex.Type.date/0","type":"type","doc":"Date as {year, month, day}"},{"ref":"Mssqlex.Type.html#t:datetime/0","title":"Mssqlex.Type.datetime/0","type":"type","doc":"Datetime"},{"ref":"Mssqlex.Type.html#t:param/0","title":"Mssqlex.Type.param/0","type":"type","doc":"Input param."},{"ref":"Mssqlex.Type.html#t:return_value/0","title":"Mssqlex.Type.return_value/0","type":"type","doc":"Output value."},{"ref":"Mssqlex.Type.html#t:time/0","title":"Mssqlex.Type.time/0","type":"type","doc":"Time as {hour, minute, sec, usec}"},{"ref":"Mssqlex.TypeParser.html","title":"Mssqlex.TypeParser","type":"module","doc":"Parser for table column data types."},{"ref":"Mssqlex.TypeParser.html#parse_rows/4","title":"Mssqlex.TypeParser.parse_rows/4","type":"function","doc":""},{"ref":"Mssqlex.TypeParser.Agent.html","title":"Mssqlex.TypeParser.Agent","type":"module","doc":"Agent for fetching and storing the table column types."},{"ref":"Mssqlex.TypeParser.Agent.html#child_spec/1","title":"Mssqlex.TypeParser.Agent.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"Mssqlex.TypeParser.Agent.html#fetch_table_columns/2","title":"Mssqlex.TypeParser.Agent.fetch_table_columns/2","type":"function","doc":""},{"ref":"Mssqlex.TypeParser.Agent.html#fetch_table_columns/3","title":"Mssqlex.TypeParser.Agent.fetch_table_columns/3","type":"function","doc":""},{"ref":"Mssqlex.TypeParser.Agent.html#start_link/1","title":"Mssqlex.TypeParser.Agent.start_link/1","type":"function","doc":""},{"ref":"readme.html","title":"Mssqlex","type":"extras","doc":"Mssqlex Adapter to Microsoft SQL Server. Using DBConnection and ODBC. It connects to Ecto with MssqlEcto."},{"ref":"readme.html#installation","title":"Mssqlex - Installation","type":"extras","doc":"Mssqlex requires the Erlang ODBC application to be installed. This might require the installation of an additional package depending on how you have installed Erlang (e.g. on Ubuntu sudo apt-get install erlang-odbc). Mssqlex depends on Microsoft&#39;s ODBC Driver for SQL Server. You can find installation instructions for Linux or other platforms on the official site. This package is availabe in Hex, the package can be installed by adding mssqlex to your list of dependencies in mix.exs: def deps do [{:mssqlex, &quot;~&gt; 2.0.0-beta.0&quot;}] end"},{"ref":"readme.html#testing","title":"Mssqlex - Testing","type":"extras","doc":"Tests require an instance of SQL Server to be running on localhost and a valid UID and password to be set in the MSSQL_UID and MSSQL_PWD environment variables, respectively. The easiest way to get an instance running is to use the SQL Server Docker image: export MSSQL_UID=sa export MSSQL_PWD=&#39;ThePa$$word&#39; docker run --name test_mssqlex_server -e &#39;ACCEPT_EULA=Y&#39; -e SA_PASSWORD=$MSSQL_PWD -p 1433:1433 -d microsoft/mssql-server-linux"},{"ref":"readme.html#known-issues","title":"Mssqlex - Known Issues","type":"extras","doc":"Fixable Needs better handling for UUIDs Requires investigation Several syntax errors occur under specific conditions (of the form &#39;syntax error near&#39;) Many-to-many doesn&#39;t seem to return duplicates Fails to autogenerate binary_id type Limited support for unique constraints Doesn&#39;t handle no association constraint correctly Problems with has_many association on delete Probably Unfixable Migrations can fail when primary keys are changed No support for transactions, locks, windows or streams. Can also cause issues for migrations if the programmer runs the migration while other operations are happening on the database. Datetime intervals not implemented Unfixable due to technical limitations The ambiguity of Transact SQL&#39;s order by statement can cause problems in more complex queries see here The following error will randomly but rarely occur &#39;Error in /usr/lib/erlang/lib/odbc-2.12.3/priv/bin/odbcserver&#39;: double free or corruption (fasttop): 0x0000000001cb75c0&#39;"}]